package Task::BeLike::BINGOS;
$Task::BeLike::BINGOS::VERSION = '1.06';
#ABSTRACT: Be the most BINGOS you can be

use strict;
use warnings;

'Looks like I picked the wrong week to quit sniffing glue.'

__END__

=pod

=encoding UTF-8

=head1 NAME

Task::BeLike::BINGOS - Be the most BINGOS you can be

=head1 VERSION

version 1.06

=head1 DESCRIPTION

Task::BeLike::BINGOS is a L<Task> module to install all the modules that I like to have
kicking around.

See the C<Makefile.PL> file in this distribution for details.

=head1 AUTHOR

Chris Williams <chris@bingosnet.co.uk>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Chris Williams.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
